<?php

namespace Drupal\standwithukraine\Service;

use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\user\RoleInterface;

/**
 * Defines the access service.
 */
class StandWithUkraineAccess implements StandWithUkraineAccessInterface {

  /**
   * The role storage.
   */
  protected EntityStorageInterface $storage;

  /**
   * StandWithUkraineAccess constructor.
   *
   * @param \Drupal\Core\Session\AccountProxyInterface $currentUser
   *   The current active user.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(
    protected AccountProxyInterface $currentUser,
    EntityTypeManagerInterface $entity_type_manager
  ) {
    $this->storage = $entity_type_manager->getStorage('user_role');
  }

  /**
   * {@inheritdoc}
   */
  public function isAllowed(string $permission): bool {
    foreach ($this->currentUser->getRoles() as $role_id) {
      $role = $this->storage->load($role_id);

      if (
        $role instanceof RoleInterface &&
        !$role->isAdmin() &&
        (
          $role->hasPermission('disable standwithukraine features') ||
          $role->hasPermission($permission)
        )
      ) {
        return FALSE;
      }
    }

    return TRUE;
  }

}
